Installation — AIscalator 0.1.0 documentation

### Navigation

- ☰
- AIscalator-0.1.0 »

Fork me on GitHub

# Installation

## Stable release

To install aiscalator, run this command in your terminal:

    $ pip install aiscalator

This is the preferred method to install aiscalator, as it will always install the most recent stable release.

If you don’t have pip installed, this Python installation guide can guide you through the process.

## From sources

The sources for aiscalator can be downloaded from the Github repo.

You can either clone the public repository:

    $ git clone git://github.com/aiscalate/aiscalator

Or download the tarball:

    $ curl  -OL https://github.com/aiscalate/aiscalator/tarball/master

Once you have a copy of the source, you can install it with:

    $ python setup.py install

### Navigation

- index
- modules |
- next |
- previous |